@@ -71,52 +71,56 @@ diags_dict['[ArIV] 7230+/4720+'] = ('Ar4', '(L(7170)+L(7263))/(L(4711)+L(4740))'
               'RMS([E(4711)*L(4711)/(L(4711)+L(4740)), E(4740)*L(4740)/(L(4711)+L(4740)), E(7170)*L(7170)/(L(7170)+L(7263)), E(7263)*L(7263)/(L(7170)+L(7263))])')
 diags_dict['[ArV] 4626/6600+'] = ('Ar5', 'L(4626)/(L(6435)+L(7005))', 'RMS([E(6435)*L(6435)/(L(6435)+L(7005)), E(7005)*L(7005)/(L(6435)+L(7005)), E(4626)])')
 
-diags_dict['[FeIII] 5272/4987'] = ('Fe3', 'L(5272)/L(4987)', 'RMS([E(5272), E(4987)])')
-diags_dict['[FeIII] 5272/4926'] = ('Fe3', 'L(5272)/L(4926)', 'RMS([E(5272), E(4926)])')
-diags_dict['[FeIII] 5272/4882'] = ('Fe3', 'L(5272)/L(4882)', 'RMS([E(5272), E(4882)])')
-diags_dict['[FeIII] 5272/5013'] = ('Fe3', 'L(5272)/L(5013)', 'RMS([E(5272), E(5013)])')
-diags_dict['[FeIII] 5272/4932'] = ('Fe3', 'L(5272)/L(4932)', 'RMS([E(5272), E(4932)])')
-diags_dict['[FeIII] 5272/4659'] = ('Fe3', 'L(5272)/L(4659)', 'RMS([E(5272), E(4659)])')
-diags_dict['[FeIII] 5272/4703'] = ('Fe3', 'L(5272)/L(4703)', 'RMS([E(5272), E(4703)])')
-diags_dict['[FeIII] 5272/4735'] = ('Fe3', 'L(5272)/L(4735)', 'RMS([E(5272), E(4735)])')
-diags_dict['[FeIII] 5272/4009'] = ('Fe3', 'L(5272)/L(4009)', 'RMS([E(5272), E(4009)])')
-diags_dict['[FeIII] 4987/4926'] = ('Fe3', 'L(4987)/L(4926)', 'RMS([E(4987), E(4926)])')
-diags_dict['[FeIII] 4987/4882'] = ('Fe3', 'L(4987)/L(4882)', 'RMS([E(4987), E(4882)])')
-diags_dict['[FeIII] 4987/5013'] = ('Fe3', 'L(4987)/L(5013)', 'RMS([E(4987), E(5013)])')
-diags_dict['[FeIII] 4987/4932'] = ('Fe3', 'L(4987)/L(4932)', 'RMS([E(4987), E(4932)])')
+diags_dict['[FeIII] 5270/4987'] = ('Fe3', 'L(5270)/L(4987)', 'RMS([E(5270), E(4987)])')
+diags_dict['[FeIII] 5270/4925'] = ('Fe3', 'L(5270)/L(4925)', 'RMS([E(5270), E(4925)])')
+diags_dict['[FeIII] 5270/4881'] = ('Fe3', 'L(5270)/L(4881)', 'RMS([E(5270), E(4881)])')
+diags_dict['[FeIII] 5270/5011'] = ('Fe3', 'L(5270)/L(5011)', 'RMS([E(5270), E(5011)])')
+diags_dict['[FeIII] 5270/4931'] = ('Fe3', 'L(5270)/L(4931)', 'RMS([E(5270), E(4931)])')
+diags_dict['[FeIII] 5270/4659'] = ('Fe3', 'L(5270)/L(4659)', 'RMS([E(5270), E(4659)])')
+diags_dict['[FeIII] 5270/4701'] = ('Fe3', 'L(5270)/L(4701)', 'RMS([E(5270), E(4701)])')
+diags_dict['[FeIII] 5270/4734'] = ('Fe3', 'L(5270)/L(4734)', 'RMS([E(5270), E(4734)])')
+diags_dict['[FeIII] 5270/4009'] = ('Fe3', 'L(5270)/L(4009)', 'RMS([E(5270), E(4009)])')
+diags_dict['[FeIII] 4987/4925'] = ('Fe3', 'L(4987)/L(4925)', 'RMS([E(4987), E(4925)])')
+diags_dict['[FeIII] 4987/4881'] = ('Fe3', 'L(4987)/L(4881)', 'RMS([E(4987), E(4881)])')
+diags_dict['[FeIII] 4987/5011'] = ('Fe3', 'L(4987)/L(5011)', 'RMS([E(4987), E(5011)])')
+diags_dict['[FeIII] 4987/4931'] = ('Fe3', 'L(4987)/L(4931)', 'RMS([E(4987), E(4931)])')
 diags_dict['[FeIII] 4987/4659'] = ('Fe3', 'L(4987)/L(4659)', 'RMS([E(4987), E(4659)])')
-diags_dict['[FeIII] 4987/4703'] = ('Fe3', 'L(4987)/L(4703)', 'RMS([E(4987), E(4703)])')
-diags_dict['[FeIII] 4987/4735'] = ('Fe3', 'L(4987)/L(4735)', 'RMS([E(4987), E(4735)])')
+diags_dict['[FeIII] 4987/4701'] = ('Fe3', 'L(4987)/L(4701)', 'RMS([E(4987), E(4701)])')
+diags_dict['[FeIII] 4987/4734'] = ('Fe3', 'L(4987)/L(4734)', 'RMS([E(4987), E(4734)])')
 diags_dict['[FeIII] 4987/4009'] = ('Fe3', 'L(4987)/L(4009)', 'RMS([E(4987), E(4009)])')
-diags_dict['[FeIII] 4926/4882'] = ('Fe3', 'L(4926)/L(4882)', 'RMS([E(4926), E(4882)])')
-diags_dict['[FeIII] 4926/5013'] = ('Fe3', 'L(4926)/L(5013)', 'RMS([E(4926), E(5013)])')
-diags_dict['[FeIII] 4926/4932'] = ('Fe3', 'L(4926)/L(4932)', 'RMS([E(4926), E(4932)])')
-diags_dict['[FeIII] 4926/4659'] = ('Fe3', 'L(4926)/L(4659)', 'RMS([E(4926), E(4659)])')
-diags_dict['[FeIII] 4926/4703'] = ('Fe3', 'L(4926)/L(4703)', 'RMS([E(4926), E(4703)])')
-diags_dict['[FeIII] 4926/4735'] = ('Fe3', 'L(4926)/L(4735)', 'RMS([E(4926), E(4735)])')
-diags_dict['[FeIII] 4926/4009'] = ('Fe3', 'L(4926)/L(4009)', 'RMS([E(4926), E(4009)])')
-diags_dict['[FeIII] 4882/5013'] = ('Fe3', 'L(4882)/L(5013)', 'RMS([E(4882), E(5013)])')
-diags_dict['[FeIII] 4882/4932'] = ('Fe3', 'L(4882)/L(4932)', 'RMS([E(4882), E(4932)])')
-diags_dict['[FeIII] 4882/4659'] = ('Fe3', 'L(4882)/L(4659)', 'RMS([E(4882), E(4659)])')
-diags_dict['[FeIII] 4882/4703'] = ('Fe3', 'L(4882)/L(4703)', 'RMS([E(4882), E(4703)])')
-diags_dict['[FeIII] 4882/4735'] = ('Fe3', 'L(4882)/L(4735)', 'RMS([E(4882), E(4735)])')
-diags_dict['[FeIII] 4882/4009'] = ('Fe3', 'L(4882)/L(4009)', 'RMS([E(4882), E(4009)])')
-diags_dict['[FeIII] 5013/4932'] = ('Fe3', 'L(5013)/L(4932)', 'RMS([E(5013), E(4932)])')
-diags_dict['[FeIII] 5013/4659'] = ('Fe3', 'L(5013)/L(4659)', 'RMS([E(5013), E(4659)])')
-diags_dict['[FeIII] 5013/4703'] = ('Fe3', 'L(5013)/L(4703)', 'RMS([E(5013), E(4703)])')
-diags_dict['[FeIII] 5013/4735'] = ('Fe3', 'L(5013)/L(4735)', 'RMS([E(5013), E(4735)])')
-diags_dict['[FeIII] 5013/4009'] = ('Fe3', 'L(5013)/L(4009)', 'RMS([E(5013), E(4009)])')
-diags_dict['[FeIII] 4932/4659'] = ('Fe3', 'L(4932)/L(4659)', 'RMS([E(4932), E(4659)])')
-diags_dict['[FeIII] 4932/4703'] = ('Fe3', 'L(4932)/L(4703)', 'RMS([E(4932), E(4703)])')
-diags_dict['[FeIII] 4932/4735'] = ('Fe3', 'L(4932)/L(4735)', 'RMS([E(4932), E(4735)])')
-diags_dict['[FeIII] 4932/4009'] = ('Fe3', 'L(4932)/L(4009)', 'RMS([E(4932), E(4009)])')
-diags_dict['[FeIII] 4659/4703'] = ('Fe3', 'L(4659)/L(4703)', 'RMS([E(4659), E(4703)])')
-diags_dict['[FeIII] 4659/4735'] = ('Fe3', 'L(4659)/L(4735)', 'RMS([E(4659), E(4735)])')
+diags_dict['[FeIII] 4925/4881'] = ('Fe3', 'L(4925)/L(4881)', 'RMS([E(4925), E(4881)])')
+diags_dict['[FeIII] 4925/5011'] = ('Fe3', 'L(4925)/L(5011)', 'RMS([E(4925), E(5011)])')
+diags_dict['[FeIII] 4925/4931'] = ('Fe3', 'L(4925)/L(4931)', 'RMS([E(4925), E(4931)])')
+diags_dict['[FeIII] 4925/4659'] = ('Fe3', 'L(4925)/L(4659)', 'RMS([E(4925), E(4659)])')
+diags_dict['[FeIII] 4925/4701'] = ('Fe3', 'L(4925)/L(4701)', 'RMS([E(4925), E(4701)])')
+diags_dict['[FeIII] 4925/4734'] = ('Fe3', 'L(4925)/L(4734)', 'RMS([E(4925), E(4734)])')
+diags_dict['[FeIII] 4925/4009'] = ('Fe3', 'L(4925)/L(4009)', 'RMS([E(4925), E(4009)])')
+diags_dict['[FeIII] 4881/5011'] = ('Fe3', 'L(4881)/L(5011)', 'RMS([E(4881), E(5011)])')
+diags_dict['[FeIII] 4881/4931'] = ('Fe3', 'L(4881)/L(4931)', 'RMS([E(4881), E(4931)])')
+diags_dict['[FeIII] 4881/4659'] = ('Fe3', 'L(4881)/L(4659)', 'RMS([E(4881), E(4659)])')
+diags_dict['[FeIII] 4881/4701'] = ('Fe3', 'L(4881)/L(4701)', 'RMS([E(4881), E(4701)])')
+diags_dict['[FeIII] 4881/4734'] = ('Fe3', 'L(4881)/L(4734)', 'RMS([E(4881), E(4734)])')
+diags_dict['[FeIII] 4881/4009'] = ('Fe3', 'L(4881)/L(4009)', 'RMS([E(4881), E(4009)])')
+diags_dict['[FeIII] 5011/4931'] = ('Fe3', 'L(5011)/L(4931)', 'RMS([E(5011), E(4931)])')
+diags_dict['[FeIII] 5011/4659'] = ('Fe3', 'L(5011)/L(4659)', 'RMS([E(5011), E(4659)])')
+diags_dict['[FeIII] 5011/4701'] = ('Fe3', 'L(5011)/L(4701)', 'RMS([E(5011), E(4701)])')
+diags_dict['[FeIII] 5011/4734'] = ('Fe3', 'L(5011)/L(4734)', 'RMS([E(5011), E(4734)])')
+diags_dict['[FeIII] 5011/4009'] = ('Fe3', 'L(5011)/L(4009)', 'RMS([E(5011), E(4009)])')
+diags_dict['[FeIII] 4931/4659'] = ('Fe3', 'L(4931)/L(4659)', 'RMS([E(4931), E(4659)])')
+diags_dict['[FeIII] 4931/4701'] = ('Fe3', 'L(4931)/L(4701)', 'RMS([E(4931), E(4701)])')
+diags_dict['[FeIII] 4931/4734'] = ('Fe3', 'L(4931)/L(4734)', 'RMS([E(4931), E(4734)])')
+diags_dict['[FeIII] 4931/4009'] = ('Fe3', 'L(4931)/L(4009)', 'RMS([E(4931), E(4009)])')
+diags_dict['[FeIII] 4659/4701'] = ('Fe3', 'L(4659)/L(4701)', 'RMS([E(4659), E(4701)])')
+diags_dict['[FeIII] 4659/4734'] = ('Fe3', 'L(4659)/L(4734)', 'RMS([E(4659), E(4734)])')
 diags_dict['[FeIII] 4659/4009'] = ('Fe3', 'L(4659)/L(4009)', 'RMS([E(4659), E(4009)])')
-diags_dict['[FeIII] 4703/4735'] = ('Fe3', 'L(4703)/L(4735)', 'RMS([E(4703), E(4735)])')
-diags_dict['[FeIII] 4703/4009'] = ('Fe3', 'L(4703)/L(4009)', 'RMS([E(4703), E(4009)])')
-diags_dict['[FeIII] 4735/4009'] = ('Fe3', 'L(4735)/L(4009)', 'RMS([E(4735), E(4009)])')
-diags_dict['[FeIII] 4659+/4987+'] = ('Fe3', '(L(4659)+L(4735)+L(4009))/(L(4987)+L(4989))', 'RMS([E(4659), E(4987)])')
+diags_dict['[FeIII] 4701/4734'] = ('Fe3', 'L(4701)/L(4734)', 'RMS([E(4701), E(4734)])')
+diags_dict['[FeIII] 4701/4009'] = ('Fe3', 'L(4701)/L(4009)', 'RMS([E(4701), E(4009)])')
+diags_dict['[FeIII] 4734/4009'] = ('Fe3', 'L(4734)/L(4009)', 'RMS([E(4734), E(4009)])')
+# To be checked:
+# 4989 is to be changed into 4987, but what about 4987?
+# which is the relationship between the 3 lines in the numerator?
+# is the error right?
+# diags_dict['[FeIII] 4659+/4987+'] = ('Fe3', '(L(4659)+L(4734)+L(4009))/(L(4987)+L(4989))', 'RMS([E(4659), E(4987)])')
 diags_dict['[NiIII] 6000/7890'] = ('Ni3', 'L(6000)/L(7890)', 'RMS([E(6000), E(7890)])')
 diags_dict['[NiIII] 6401/7890'] = ('Ni3', 'L(6401)/L(7890)', 'RMS([E(6401), E(7890)])')
 diags_dict['[NiIII] 6534/7890'] = ('Ni3', 'L(6534)/L(7890)', 'RMS([E(6534), E(7890)])')
