@@ -129,12 +129,16 @@ class ICF(object):
                                        'icf': '(0.753 + 0.142 * abun["O3"] / (abun["O2"] + abun["O3"]) + 0.171 / abun["O3"] * (abun["O2"] + abun["O3"]))',
                                        'type': 'HII',
                                        'comment': 'Based on a grid of photoionization models'},
-                         'PHCD07_14': {'elem': 'Ar',
+# Cited in PHCD07 but originally proposed by ITL94. Authorship changed in the code 3/Nov/2014. 
+#                         'PHCD07_14': {'elem': 'Ar',
+                         'ITL94_19': {'elem': 'Ar',
                                        'atom': '(abun["Ar2"] + abun["Ar3"])',
                                        'icf': '(0.99 + 0.091 * abun["O2"] / (abun["O2"] + abun["O3"]) - 1.14 * (abun["O2"] / (abun["O2"] + abun["O3"]))**2. + 0.077 * (abun["O2"] / (abun["O2"] + abun["O3"]))**3.)**-1.',
                                        'type': 'HII',
                                        'comment': 'Based on a grid of photoionization models'},
-                         'PHCD07_15': {'elem': 'Ar',
+# Cited in PHCD07 but originally proposed by ITL94. Authorship changed in the code 3/Nov/2014. 
+#                         'PHCD07_15': {'elem': 'Ar',
+                         'ITL94_20': {'elem': 'Ar',
                                        'atom': 'abun["Ar3"]',
                                        'icf': '(0.15 + 2.39 * abun["O2"] / (abun["O2"] + abun["O3"]) - 2.64 * (abun["O2"] / (abun["O2"] + abun["O3"]))**2.)**-1.',
                                        'type': 'HII',
@@ -505,6 +509,8 @@ class ICF(object):
                                       'url': 'http://adsabs.harvard.edu/abs/1994MNRAS.271..257K'},
                              'KH01': {'ref': 'Kwitter & Henry 2001, ApJ, 562, 804',
                                       'url': 'http://adsabs.harvard.edu/abs/2001ApJ...562..804K'},
+                             'ITL94': {'ref': 'Izotov, Thuan & Lipovetsky 1994, ApJ, 435, 647',
+                                       'url': 'http://http://adsabs.harvard.edu/abs/1994ApJ...435..647I'},
                              'Ial06': {'ref': 'Izotov et al 2006, A&A, 448, 955',
                                        'url': 'http://adsabs.harvard.edu/abs/2006A%26A...448..955I'},
                              'PC69': {'ref': 'Peimbert & Costero 1969, BOTT, 5, 3',
