@@ -58,18 +58,19 @@ class RedCorr(object):
         self.calling = 'RedCorr'
         self._laws_dict = {} # dictionary pointing to a reddening function depending on the key
         self._laws_dict['No correction'] = self._zeros
-        self._laws_dict['CCM 89'] = self._CCM89
-        self._laws_dict['B 07'] = self._B07
-        self._laws_dict['oD 94'] = self._oD94
-        self._laws_dict['S 79 H 83'] = self._SH
+        self._laws_dict['CCM89'] = self._CCM89
+        self._laws_dict['CCM89 Bal07'] = self._CCM89_Bal07
+        self._laws_dict['CCM89 oD94'] = self._CCM89_oD94
+        self._laws_dict['S79 H83 CCM89'] = self._S79_H83_CCM89
         #self._laws_dict['GCC 09'] = self._GCC09 
-        self._laws_dict['K 76'] = self._K76
-        self._laws_dict['Gal SM 79'] = self._Gal_SM79
-        self._laws_dict['LMC G 03'] = self._LMC_Gordon03
-        self._laws_dict['Fitz'] = self._Fitz
-        self._laws_dict['Fitz IDL'] = self._Fitz_IDL
-        self._laws_dict['Fitz 99'] = self._Fitz_99
-        self._laws_dict['Fitz AVGLMC'] = self._Fitz_AVGLMC
+        self._laws_dict['K76'] = self._K76
+        self._laws_dict['SM79 Gal'] = self._SM79_Gal
+        self._laws_dict['G03 LMC'] = self._G03_LMC
+        self._laws_dict['MCC99 FM90 LMC'] = self._MCC99_FM90_LMC
+        self._laws_dict['F99-like'] = self._F99_like
+        #self._laws_dict['F99-like IDL'] = self._F99_like_IDL
+        self._laws_dict['F99'] = self._F99
+        self._laws_dict['F88 F99 LMC'] = self._FM88_F99_LMC
 
         self.UserFunction = UserFunction
         self.UserParams = None
@@ -88,8 +89,8 @@ class RedCorr(object):
  
     def cHbetaFromEbv(self, ebv):
         """
-        Return cHebta from B(BV)
-        Using: 
+        Return cHbeta from E(BV)
+        Usage: 
             (1-f_lambda).cHbeta = 0.4.EBV.X_lambda applied to lambda = 4861, with f_beta = 0.:
             cHbeta = 0.4 . EBV . X_beta
         
@@ -310,6 +311,7 @@ class RedCorr(object):
             laws = self.getLaws()
         if type(laws) is str:
             laws = [laws]
+        laws = laws.sort()    
         for i, law in enumerate(laws):
             self.law = law
             corr = self.getCorrHb(w)
@@ -320,6 +322,7 @@ class RedCorr(object):
         plt.ylabel('X')
         self.law = old_law
         self.E_BV = old_E_BV
+    
                             
     def _CCM89(self, wave):
         """
@@ -369,8 +372,11 @@ class RedCorr(object):
         return np.squeeze(Xx)
 
 
-    def _B07(self, wave):
+    def _CCM89_Bal07(self, wave):
         """
+        Galactic extinction law based on Cardelli et al 1989, modified by Blagrave et al 2007 
+        for 3.3 < x < 8 (1250 < lambda < 3030)
+        
         Blagrave et al 2007, ApJ, 655, 299 
         http://adsabs.harvard.edu/abs/2007ApJ...655..299B
         Cardelli, Clayton & Mathis 1989, ApJ 345, 245
@@ -421,8 +427,11 @@ class RedCorr(object):
         Xx = self.R_V * a + b
         return np.squeeze(Xx)
 
-    def _oD94(self, wave):
+    def _CCM89_oD94(self, wave):
         """
+        Galactic extinction law based on Cardelli et al 1989, modified by O'Donnel 1994
+        for 1.1 < x < 3.3 (9100 < lambda < 3030)
+        
         O'Donnell 1994, ApJ, 422, 1580
         http://adsabs.harvard.edu/abs/1994ApJ...422..158O
         Cardelli, Clayton & Mathis 1989, ApJ 345, 245
@@ -471,32 +480,46 @@ class RedCorr(object):
         Xx = self.R_V * a + b
         return np.squeeze(Xx)
 
-    def _SH(self, wave):
+    def _S79_H83_CCM89(self, wave):
         """
-        Seaton (1979: MNRAS 187, 73) and 
-        Howarth (1983, MNRAS 203, 301) Galactic law
+        Galactic extinction law (0-33000 A range):
+        - In the UV, from Seaton 1979
+        - In the opt/NIR (3600-9100) Howarth 1983
+        - In the FIR (9100-33000) Cardelly et al 1989
         
+        Seaton 1979, MNRAS, 187, 73) and 
         http://adsabs.harvard.edu/abs/1979MNRAS.187P..73S
+        Howarth 1983, MNRAS, 203, 301) Galactic law
+        http://adsabs.harvard.edu/abs/1983MNRAS.204.1091H
+        Cardelli, Clayton and Mathis 1989, ApJ, 345, 245
+        http://adsabs.harvard.edu/abs/1989ApJ...345..245C
+        
         
         """
         x = 1e4 / np.asarray([wave]) # inv microns
         Xx = np.zeros_like(x)
 
+        # Cardelli, Clayton & Mathis 1989 33000-9000
         tt = (x > 0.3) & (x <= 1.1)
         Xx[tt] = self.R_V * (0.574 * x[tt] ** 1.61) - 0.527 * x[tt] ** 1.61
-
+        
+        # Howarth 1983, Galactic 9000-5000
         tt = (x > 1.1) & (x <= 1.83)
         Xx[tt] = (self.R_V - 3.1) + ((1.86 - 0.48 * x[tt]) * x[tt] - 0.1) * x[tt]
         
+        # Howarth 1983, Galactic 5000-3600
         tt = (x > 1.83) & (x <= 2.75)
         Xx[tt] = self.R_V + 2.56 * (x[tt] - 1.83) - 0.993 * ((x[tt] - 1.83) ** 2)
 
+        # Seaton 1979, Galactic
         tt = (x > 2.75) & (x <= 3.65)
         Xx[tt] = (self.R_V - 3.2) + 1.56 + 1.048 * x[tt] + 1.01 / (((x[tt] - 4.6) ** 2) + 0.280)
         
+        # Seaton 1979, Galactic
         tt = (x > 3.65) & (x <= 7.14)
         Xx[tt] = (self.R_V - 3.2) + 2.29 + 0.848 * x[tt] + 1.01 / (((x[tt] - 4.6) ** 2) + 0.280)
         
+        # Seaton 1979, Galactic
         tt = (x > 7.14) 
         Xx[tt] = (self.R_V - 3.2) + 16.17 - 3.20 * x[tt] + 0.2975 * x[tt] ** 2
  
@@ -571,8 +594,9 @@ class RedCorr(object):
         f = np.interp(w, f_tab[:, 0], f_tab[:, 1])
         return np.squeeze(f * self.cHbeta / 0.4 / self.E_BV)
 
-    def _Gal_SM79(self, wave):
+    def _SM79_Gal(self, wave):
         """
+        Galactic extinction law
         Savage & Mathis 1979, ARA&A, 17, 73
         http://adsabs.harvard.edu/abs/1979ARA%26A..17...73S
         
@@ -591,8 +615,9 @@ class RedCorr(object):
         Xx = np.interp(x, X_tab[:, 0], X_tab[:, 1])
         return np.squeeze(Xx)
     
-    def _LMC_Gordon03(self, wave):
+    def _G03_LMC(self, wave):
         """
+        Extinction curve for the LMC
         Gordon et al. (2003, ApJ, 594,279)
         http://adsabs.harvard.edu/abs/2003ApJ...594..279G
         
@@ -611,17 +636,20 @@ class RedCorr(object):
         return np.squeeze(Xx)
     
     
-    def _Fitz(self, wave):
+    def _F99_like(self, wave):
         """
+        In the UV, it returns the Fitzpatrick & Massa 1990 law.
+        In the opt/IR, it returns the Fitzpatrick 1990 law. 
+        
         Fitzpatrick 1999, PASP, 11, 63
         http://adsabs.harvard.edu/abs/1999PASP..111...63F
-        Fitzpatrick & Massa 1988, ApJ, 328, 734
-        http://adsabs.harvard.edu/abs/1988ApJ...328..734F
+        Fitzpatrick & Massa 1990, ApJS, 72, 163
+        http://adsabs.harvard.edu/abs/1990ApJS...72..163F
         
         Comments:
-        The Fitzpatrick law in the UV depends on 6 parameters, stored in RedCorr.FitzParams 
-        and either set by the user or predefined
-        Depends on R_V; the dependence with R_V follows Table 4 in the F99 paper 
+        The FM90 depends on 6 parameters which must be set by the user and are stored in RedCorr.FitzParams.
+        For the predefined set of parameters defined in FM99, use instead the F_99 method.
+        R_V must be provided, as the law depends on it. The dependence with R_V follows Table 4 in the F99 paper 
 
         Scope:    
         Range: UV through IR
@@ -670,21 +698,30 @@ class RedCorr(object):
         return np.squeeze(Xx)
 
 
-    def _Fitz_IDL(self, wave):
+# Commented out because it duplicates _F99_like
+#    def _F99_like_IDL(self, wave):
         """
+        Same as F99_like, but with a different function in the opt/IR fitting, based on an IDL program
+        provided by F99. The results should be identical.
+    
+        In the UV, it returns the Fitzpatrick & Massa 1990 law.
+        In the opt/IR, it returns the Fitzpatrick 1990 law. 
+        
         Fitzpatrick 1999, PASP, 11, 63
         http://adsabs.harvard.edu/abs/1999PASP..111...63F
-        Fitzpatrick & Massa 1988, ApJ, 328, 734
-        http://adsabs.harvard.edu/abs/1988ApJ...328..734F
+        Fitzpatrick & Massa 1990, ApJS, 72, 163
+        http://adsabs.harvard.edu/abs/1990ApJS...72..163F
         
         Comments:
-        The Fitzpatrick law in the UV depends on 6 parameters, stored in RedCorr.FitzParams and 
-        either set by the user or predefined
-        Depends on R_V; the dependence with R_V follows the interpolation of the IDL routine mentioned in the F99 paper 
+        The FM90 depends on 6 parameters which must be set by the user and are stored in RedCorr.FitzParams.
+        For the predefined set of parameters defined in FM99, use instead the F_99 method.
+        R_V must be provided, as the law depends on it. The dependence with R_V follows Table 4 in the F99 paper 
+
+        Scope:    
+        Range: UV through IR
         
-        Scope:
-        UV through IR
         
+        """
         """
         def fit_UV(x):
 
@@ -729,20 +766,58 @@ class RedCorr(object):
             tck = interpolate.splrep(x_opir, y_opir)
             Xx[tt] = interpolate.splev(x[tt], tck, der=0)
         return np.squeeze(Xx)
+        """    
             
-            
-    def _Fitz_99(self, wave):
+    def _MCC99_FM90_LMC(self, wave):
         """
-        Sets RedCorr.FitzParams
-        
-        Fitzpatrick 1999, PASP, 11, 63
-        http://adsabs.harvard.edu/abs/1999PASP..111...63F
+        This method returns the UV extinction curve proposed for the LMC 
+        by Misselt et al 1989 based on the 1990 variant of the Fitzpatrick & Massa law
+
+        Misselt, Clayton & Gordon 1989 , ApJ, 515, 128 
+        http://adsabs.harvard.edu/abs/1999ApJ...515..128M
+        Fitzpatrick & Massa 1990, ApJS, 72, 163
+        http://adsabs.harvard.edu/abs/1990ApJS...72..163F
         
         Comments:
-        The Fitzpatrick law in the UV depends on 6 parameters, stored in RedCorr.FitzParams.
-        This method defines the default set.
-        Other sets can be chosen to fit specific extinction curves in the UV
-        Depends on R_V
+        The Fitzpatrick & Massa 1990 law in the UV depends on 6 parameters, stored in RedCorr.FitzParams.
+        The method sets RedCorr.FitzParams to the values of set in the Fitzpatrick 1999 paper, 
+        which includes an explicit dependence on R_V.
+        R_V must be provided, as the law depends on its value.
+        We refer to FM90 and not to the original FM88 because the value of a constant in F(lambda) slightly changed (0.0564 -> 0.05644)
+        The value of another constant of F(lambda) appears to change from FM90 to MCC99, but it is probably a typo (0.5392 -> 0.5329) 
+        
+        Scope:
+        Only UV
+
+        """
+        if (wave > 3125.): # The cutoff is taken from Fig 3 of MCC99. Couldn't find the number anywhere.
+            pn.log_.warn('MCC89 law only defined for lambda < 3125A', calling=self.calling)
+            return None
+        x0 = 4.596  
+        gamma = 0.91
+        c1 = -1.28
+        c2 = 1.11    
+        c3 = 2.73    
+        c4 = 0.64    
+        self.FitzParams = [x0, gamma, c1, c2, c3, c4]
+        return self._F99_like(wave)
+
+
+    def _F99(self, wave):
+        """
+        This method returns the R-dependent IR-through-UV extinction curve proposed by Fitzpatrick 1999.
+
+        Fitzpatrick 1999, PASP, 11, 63
+        http://adsabs.harvard.edu/abs/1999PASP..111...63F
+        based on: 
+        Fitzpatrick & Massa 1990, ApJS, 72, 163
+        http://adsabs.harvard.edu/abs/1990ApJS...72..163F
+        
+        Comments:
+        The Fitzpatrick & Massa 1990 law in the UV depends on 6 parameters, stored in RedCorr.FitzParams.
+        The method sets RedCorr.FitzParams to the values of set in the Fitzpatrick 1999 paper, 
+        which includes an explicit dependence on R_V.
+        R_V must be provided, as the law depends on its value.
         
         Scope:
         UV through IR
@@ -755,25 +830,24 @@ class RedCorr(object):
         c2 = -0.824 + 4.717 / self.R_V # 0.7 if RV=3.1
         c1 = 2.030 - 3.007 * c2 # -0.0677 if RV = 3.1
         self.FitzParams = [x0, gamma, c1, c2, c3, c4]
-        return self._Fitz(wave)
+        return self._F99_like(wave)
 
 
-    def _Fitz_AVGLMC(self, wave):
+    def _FM88_F99_LMC(self, wave):
         """
+        This method returns:
+        - in the UV, the average LMC extinction curve derived by Fitzpatrick & Massa 1988
+        - in the opt/IR, the R-dependent extinction curve proposed by Fitzpatrick 1999.
+        
         Fitzpatrick 1999, PASP, 11, 63
         http://adsabs.harvard.edu/abs/1999PASP..111...63F
         Fitzpatrick & Massa 1988, ApJ, 328, 734
         http://adsabs.harvard.edu/abs/1988ApJ...328..734F
-        Misselt, Clayton and Gordon 1999, ApJ, 515, 128
-        http://adsabs.harvard.edu/abs/1999ApJ...515..128M
         
         Comments:
-        The Fitzpatrick law in the UV depends on 6 parameters, stored in RedCorr.FitzParams and 
-        either set by the user or predefined
-        This method defines a set of parameters appropriate for the LMC according to the Mal99 paper
-        Other sets can be chosen to fit specific extinction curves in the UV
-        In the Opt/IR, same as Fitz
-        Depends on R_V
+        The Fitzpatrick and Massa law in the UV depends on 6 parameters, stored in RedCorr.FitzParams and 
+        here set to the LMC values derived in FM88
+        R_V must be provided, as the law depends on it
         
         Scope:
         UV through IR
@@ -786,7 +860,7 @@ class RedCorr(object):
         c3 = 2.55
         c4 = 0.504  
         self.FitzParams = [x0, gamma, c1, c2, c3, c4]
-        return self._Fitz(wave)
+        return self._F99_like(wave)
     
     def _zeros(self, wave):
         """
