@@ -11,19 +11,20 @@ if pn.config.INSTALLED['plt']:
     import matplotlib.ticker
     from matplotlib.ticker import MaxNLocator
 
-from pyneb.utils.misc import int_to_roman
-
+from pyneb.utils.misc import int_to_roman, parseAtom
 
 class DataPlot(object):
     """
     Plot transition probabilities and collision strengths from different data sets
     
     """
-    def __init__(self, elem, spec, all_data=[], n_tem_points=10000, ref_tem=None, OmegaInterp='Cheb'):
+    def __init__(self, elem=None, spec=None, all_data=[], atom=None, n_tem_points=10000, 
+                 ref_tem=None, OmegaInterp='Cheb'):
         """
     Parameters:
         - elem         atomic elem 
         - spec       ionization stage in spectroscopic notation (I = 1, II = 2, etc.)
+        - atom        e.g. 'O3'
         - all_data       dictionary of all_data to be compared (see above for format)
         - [n_tem_points] number of points in the fit (default=100; increase if fit is not smooth)
         - [ref_tem]      array of temperature values to be signaled in the plots
@@ -37,9 +38,18 @@ class DataPlot(object):
 
         
         """
-        colors = ['r', 'g', 'b', 'm', 'c', 'y']
+        colors = np.array(['r', 'g', 'b', 'm', 'c', 'y'])
         self.calling = 'DataPlot'
-        old_data = pn.atomicData.getDataFile(elem + str(spec))
+        if atom is not None:
+            self.atom = str.capitalize(atom)
+            self.elem = parseAtom(self.atom)[0]
+            self.spec = int(parseAtom(self.atom)[1])
+        else:
+            self.elem = str.capitalize(elem)
+            self.spec = int(spec)
+            self.atom = self.elem + str(self.spec)
+
+        old_data = pn.atomicData.getDataFile(self.atom)
         # Check if matplotlib installed
         if not pn.config.INSTALLED['plt']:
             pn.log_.warn('Matplotlib not installed!', calling=self.calling)
@@ -48,15 +58,15 @@ class DataPlot(object):
         atom_data = []
         coll_data = []
         if all_data == []:
-            all_data = pn.atomicData.getAllAvailableFiles(elem + str(spec))
-        i = 0    
+            all_data = pn.atomicData.getAllAvailableFiles(self.atom)
+        i_colors = 0    
         for file_ in all_data:
-            ID = (file_.split('_')[-1]).split('.fits')[0]
-            type_ = (file_.split('_')[2]).split('.fits')[0]
+            ID = file_.split('_')[-1]
+            type_ = (file_.split('_')[2]).split('.')[0]
             if type_ in ['atom', 'coll']:
                 data_list = type_ + '_data'
-                vars()[data_list].append({'ID': ID, 'file_': file_, 'type': type_, 'color': colors[i % 6]})
-                i = i + 1
+                vars()[data_list].append({'ID': ID, 'file_': file_, 'type': type_, 'color': colors[i_colors % len(colors)]})
+                i_colors += 1
                 
         self.atom_data = atom_data
         self.coll_data = coll_data
@@ -67,34 +77,43 @@ class DataPlot(object):
         else:
             self.ref_tem = ref_tem
 
-        # Atom
-        self.elem = str.capitalize(elem)
-        self.spec = spec
-        # n_max = max value of NLevels. Used to format the collision strength plot.
-        self.atom_n_max = 0
-        self.coll_n_max = 0
+        # If it's not standard effective collision strengths, we don't want it
+        coll_data_temp=[]
+        for item in self.coll_data: 
+            coll_data_temp.append(item)
+        for data in coll_data_temp:
+            pn.atomicData.setDataFile(data['file_'])
+            atom = pn.Atom(self.elem, self.spec, OmegaInterp=OmegaInterp)
+            try:
+                if ('COEFF' in atom.CollData.comments.keys()) or ('O_UNIT' in atom.CollData.comments.keys()):
+                    self.coll_data.remove(data)
+            except:
+                pass
+
         # For each data set, an atom is built. 
+        del(atom)
         for data in self.atom_data + self.coll_data:
             pn.atomicData.setDataFile(data['file_'])
-            atom = pn.Atom(elem, spec, OmegaInterp=OmegaInterp)
+            atom = pn.Atom(self.elem, self.spec, OmegaInterp=OmegaInterp)
             data['atom'] = atom
-            # n_max can be different in atom and coll data
-            if data in self.atom_data:
-                self.atom_n_max = max(self.atom_n_max, atom.atomNLevels)
-            elif data in self.coll_data:
-                self.coll_n_max = max(self.coll_n_max, atom.collNLevels)
         for data in old_data:
             if data is not None:
                 pn.atomicData.setDataFile(data)
-        self.atom = string.lower(self.elem + '_' + int_to_roman(int(self.spec)))
-        try:
-            self.level_diagram = pn.atomicData.plot_path + atom.gs + '.png'
-        except:
-            pass
+        self.atom_rom = string.lower(self.elem + '_' + int_to_roman(int(self.spec)))
         self.n_tem_points = n_tem_points
 
-                
-    def plotA(self, save=False, figsize=[18, 12], fignum=None):
+        self.atom_n_max = 0
+        for at in self.atom_data:
+            if at['atom'].atomFileType != 'chianti':
+                if at['atom'].atomNLevels > self.atom_n_max:
+                    self.atom_n_max = at['atom'].atomNLevels
+        self.coll_n_max = 0
+        for at in self.coll_data:
+            if at['atom'].collFileType != 'chianti':
+                if at['atom'].collNLevels > self.coll_n_max:
+                    self.coll_n_max = at['atom'].collNLevels
+                                    
+    def plotA(self, save=False, figsize=(18, 12), fignum=None, NLevels=None):
         """
         Plot the log of the A values of each data set 
         
@@ -104,12 +123,16 @@ class DataPlot(object):
             - fignum    figure Number
 
         """
+        if NLevels is None:
+            atom_n_max = self.atom_n_max
+        else:
+            atom_n_max = NLevels
         if not pn.config.INSTALLED['plt']:
             pn.log_.error('Matplotlib not installed!', calling=self.calling)
-        plt.figure(fignum)
+        plt.figure(fignum, figsize=figsize)
         plt.clf()
         ax = plt.subplot(111, axisbg='Ivory')
-        x = np.arange(self.atom_n_max * (self.atom_n_max - 1) / 2.)
+        x = np.arange(atom_n_max * (atom_n_max - 1) / 2.)
         ticks = x
         # Inventory of markers. Chosen to be distinguished even when overlapped
         mark = ['<', (5, 1), '>', 'o', '|']
@@ -117,17 +140,17 @@ class DataPlot(object):
         # Background colors to distinguish lower levels 
         bg_color_sequence = ['g', 'r', 'b', 'y', 'm', 'c']
         # The following command replicates the string to allocate a sufficient number of colors
-        bg_color = bg_color_sequence * (int(self.atom_n_max - 2) / len(bg_color_sequence) + 1)
+        bg_color = bg_color_sequence * (int(atom_n_max - 2) / len(bg_color_sequence) + 1)
         tick_label = []
         
-        for i in range(self.atom_n_max - 1):
+        for i in range(atom_n_max - 1):
             # x0, x1 are start and end points of each level
-            x0 = i * (self.atom_n_max - 1) - i * (i - 1) / 2 - 0.5
-            width = self.atom_n_max - i - 1
+            x0 = i * (atom_n_max - 1) - i * (i - 1) / 2 - 0.5
+            width = atom_n_max - i - 1
             x1 = x0 + width
             plt.axvspan(x0, x1, facecolor=bg_color[i], alpha=0.05)
             # The x axis must stretch the maximum range (although some data set might have a lower n_level)
-            for j in range(i + 1, self.atom_n_max):
+            for j in range(i + 1, atom_n_max):
                 tick_label.append('(' + str(j + 1) + ', ' + str(i + 1) + ')')
 
 
@@ -158,11 +181,11 @@ class DataPlot(object):
         plt.show()      
         if save:
             plt.figure(figsize=[18, 12])
-            plt.savefig(self.atom + '_' + data['ID'] + "-" + self.ref_data + "_A.pdf")
+            plt.savefig(self.atom_rom + '_' + data['ID'] + "-" + self.ref_data + "_A.pdf")
 
 
 
-    def plotAllA(self, save=False, figsize=[18, 12], fignum=None):
+    def plotAllA(self, save=False, figsize=(18, 12), fignum=None, NLevels=None):
         """
         Plot the log of the A values of each data set 
         
@@ -172,45 +195,55 @@ class DataPlot(object):
             - fignum    figure Number
 
         """
+        if NLevels is None:
+            atom_n_max = self.atom_n_max
+        else:
+            atom_n_max = NLevels
         if not pn.config.INSTALLED['plt']:
             pn.log_.error('Matplotlib not installed!', calling=self.calling)
-        fig = plt.figure(fignum)
+        fig = plt.figure(fignum, figsize=figsize)
         plt.clf()
         max_y_ticks = 6
-        ticks = range(len(self.atom_data)+1)[1:] 
+        ticks = np.arange(len(self.atom_data)+1)[1:] 
         
-        A = np.zeros([len(self.atom_data), self.atom_n_max, self.atom_n_max])
+        A = np.zeros([len(self.atom_data), atom_n_max, atom_n_max])
         color=[]
         for i, data in enumerate(self.atom_data):
-            A[i, :] = data['atom'].getA()
+            A_tmp = data['atom'].getA()
+            if A_tmp.shape[0] > atom_n_max:
+                A[i, :] = A_tmp[0:atom_n_max, 0:atom_n_max]
+            else:
+                A[i, 0:A_tmp.shape[0], 0:A_tmp.shape[1]] = A_tmp
             color.append(data['color'])
         
         A[np.where((A<=0))] = np.NaN
         lgA = np.log10(A)
-
-        for j in range(2, self.atom_n_max+1):
+        
+        x = ticks
+        color = np.array(color)
+        for j in range(2, atom_n_max+1):
             for i in range(1, j):
-                x = ticks
                 y = lgA[:, j-1, i-1]
-                ax = plt.subplot(self.atom_n_max - 1, self.atom_n_max - 1, (self.atom_n_max-1)*(j-2) + i,
+                ax = plt.subplot(atom_n_max - 1, atom_n_max - 1, (atom_n_max-1)*(j-2) + i,
                                  axisbg='#FFFFE0')
                 ax.set_xticks(x)
                 plt.xlim((min(x)-0.5, max(x)+0.5))
-                if ((j == self.atom_n_max) and (i == 1)):
-                    plt.xlabel('Reference #', fontsize=8)
-                    plt.ylabel('Log(A$_{ji}$)', fontsize=8)
                 ax.yaxis.set_major_locator(MaxNLocator(max_y_ticks-1))
-                plt.tight_layout(pad=0.1)
-                plt.subplots_adjust(left=0.15, right=0.95, top=0.95, bottom=0.12)
-                plt.gca().get_yaxis().get_major_formatter().set_useOffset(False)
-                plt.draw()
                 try:
-                    plt.scatter(x, y, color=color, label='_nolegend_')
-                    lbl = "(" + str(j) + r"$\to$" + str(i) + ")"
+                    plt.scatter(x, y, c=color, label='_nolegend_', s=40)
+                    lbl = '({0} -> {1})'.format(j,i)
                     ax.text(0.95, 0.95, lbl, fontsize=10, color="#660066", transform=ax.transAxes, ha="right", va="top")                                    
                 except:
-                    pn.log_.warn('Problem with plotting a subplot', calling=self.calling)
-
+                    pn.log_.warn('Problem with plotting a subplot {} {}'.format(i,j), calling=self.calling)
+        
+        plt.tight_layout(pad=0.1)
+        plt.subplots_adjust(left=0.15, right=0.95, top=0.95, bottom=0.12)
+        plt.gca().get_yaxis().get_major_formatter().set_useOffset(False)
+        ax=plt.subplot(atom_n_max - 1, atom_n_max - 1, (atom_n_max-1)*(atom_n_max-2) + 1)
+        plt.xlabel('Reference #', fontsize=8)
+        plt.ylabel('Log(A$_{ji}$)', fontsize=8)
+        ax.set_xticks(x)
+        
         fig.text(.5, .05, "i (lower level)", fontsize=12, ha='center', color="#660066", va='top')
         fig.text(.05, .5, "j (upper level)", ha='left', va='center', fontsize=12, color="#660066", rotation=90)
         title = "Available transition probabilities for {0} {1}".format(self.elem, int_to_roman(int(self.spec)))
@@ -221,13 +254,12 @@ class DataPlot(object):
             fig.text(x_txt, y_txt, "Ref. %d: %s" %(i+1, data['ID']), color=color[i], ha = 'right') 
 
         if save:
-            plt.figure(figsize=[18, 12])
-            plt.savefig(self.atom + "_all_As.pdf")
+            plt.savefig(self.atom_rom + "_all_As.pdf")
     
         plt.show()      
         
 
-    def plotRelA(self, ref_data=None, save=False, figsize=[18, 12], fignum=None):
+    def plotRelA(self, ref_data=None, save=False, figsize=(18, 12), fignum=None, NLevels=None):
         """
         Plot the relative difference of the A of each data set with respect to the reference one
 
@@ -238,11 +270,15 @@ class DataPlot(object):
             - fignum         figure number
 
         """
+        if NLevels is None:
+            atom_n_max = self.atom_n_max
+        else:
+            atom_n_max = NLevels
         if not pn.config.INSTALLED['plt']:
             pn.log_.error('Matplotlib not installed!', calling=self.calling)
-        plt.figure(fignum)
+        plt.figure(fignum, figsize=figsize)
         plt.clf()
-        ticks = range(self.atom_n_max + 1)[1:]
+        ticks = range(atom_n_max + 1)[1:]
 
         # The As of the reference data set are stored
         if ref_data is None:
@@ -323,13 +359,12 @@ class DataPlot(object):
                     pn.log_.warn('Problem in plotting relA', calling='DatasetPlot')
 
                 if save:
-                    plt.figure(figsize=[18, 12])
-                    plt.savefig(self.atom + '_' + data['ID'] + "-" + ref_data + "_relA.pdf")
+                    plt.savefig(self.atom_rom + '_' + data['ID'] + "-" + ref_data + "_relA.pdf")
     
                 plt.show()      
 
 
-    def plotOmega(self, save=False, figsize=[18, 12], fignum=None, scan_orders=None):
+    def plotOmega(self, save=False, figsize=(18, 12), fignum=None, scan_orders=None, NLevels=None):
         """
         Plot the tabulated collision strengths of each data set and the fit that is performed by PyNeb
         
@@ -340,17 +375,23 @@ class DataPlot(object):
             - scan_orders = None or (min_order, max_order) or (min_order, -1) to go until the max. DEPRECATED!!!
 
         """
+        if NLevels is None:
+            coll_n_max = self.coll_n_max
+        else:
+            coll_n_max = NLevels
         # Plotting range somewhat larger than actual data range (less tight) 
         if not pn.config.INSTALLED['plt']:
             pn.log_.error('Matplotlib not installed!', calling=self.calling)
-        fig = plt.figure(fignum)
+        fig = plt.figure(fignum, figsize=figsize)
         plt.autoscale(tight=False)
+        # I need two 
         first = True
+        first_done = False
         plt.clf()
         
         legend_text = []
         legend_lines = []
-        style_dic = ['-', '--', '-.', ':'] * 10
+#        style_dic = ['-', '--', '-.', ':'] * 10
         for data in self.coll_data:
             # tem_points = tabulated temperature points (different for each data set)
             tem_points = self.tem_in_K(data['atom'].tem_units, data['atom'].getTemArray())
@@ -358,71 +399,58 @@ class DataPlot(object):
             tem_max = max(tem_points)
             # tem_funct = array of temperature values for which the fit is evaluated
             tem_funct = np.linspace(tem_min, tem_max, self.n_tem_points)
+            x_dots = np.log10(tem_points)
+            x_lines = np.log10(tem_funct)
             # Loops over all levels
-            for i in range(1, self.coll_n_max):
-                for j in range(i + 1, self.coll_n_max + 1):                
+            for i in range(1, coll_n_max+1):
+                for j in range(i + 1, coll_n_max+1):                
                         # N levels require an N-1 x N-1 array of plots
                         # The subplots are arranged in rows and columns according to the upper and lower levels
-                        ax = plt.subplot(self.coll_n_max - 1, self.coll_n_max - 1, (self.coll_n_max - 1) * (j - 2) + i,
+ 
+                        ax = plt.subplot(coll_n_max-1, coll_n_max-1, 
+                                         (coll_n_max-1) * (j - 2) + i,
                                          axisbg='#FFFFE0')
-                        try:
-                            ax.plot((np.log10(tem_points)), data['atom'].getOmega(tem_points,j, i), color=data['color'],
-                                    marker='o', linestyle='None', label='_nolegend_')
-                        except:
-                            pn.log_.warn('Problem with plotting a data set', calling=self.calling)
-                        ylim = ax.get_ylim()
-                        if scan_orders is None:
+                        if (i <= data['atom'].collNLevels) and (j <= data['atom'].collNLevels):
                             try:
-                                ax.plot((np.log10(tem_funct)), data['atom'].getOmega(tem_funct, j, i),
-                                         label='_nolegend_')
+                                y_dots = data['atom'].getOmegaArray(j, i)
+                                if y_dots.sum() > 0.0:
+                                    ax.plot(x_dots, y_dots, color=data['color'],
+                                            marker='o', linestyle='None', label='_nolegend_')
+                                y_lines = data['atom'].getOmega(tem_funct, j, i)
+                                if y_lines.sum() > 0.:
+                                    ax.plot(x_lines, y_lines,
+                                            color=data['color'], label='_nolegend_')
                             except:
                                 pn.log_.warn('Problem with plotting a data set', calling=self.calling)
-                        else:
-                            pass
-                        """
-                                        # Store the Chebyshev orders
-                            ChebOrder = data['atom']._ChebOrder 
-
-                            min_order = scan_orders[0]
-                            if scan_orders[1] == -1:
-                                max_order = np.max(ChebOrder)
-                            else:
-                                max_order = scan_orders[1]
-                            for order in np.arange(min_order, max_order + 1):
-                                data['atom']._ChebOrder = np.ones_like(ChebOrder) * order
-                                try:
-                                    ax.plot((np.log10(tem_funct)), data['atom'].getOmega(tem_funct, j, i),
-                                            color=data['color'], label='_nolegend_', linestyle=style_dic[order])
-                                except:
-                                    pn.log_.warn('PB with plot order {0}'.format(order))
-                            data['atom']._ChebOrder = ChebOrder
-                            plt.ylim(ylim)
-                        """
-                        # Draws vertical lines at selected temperature values (only once for each subplot, hence "first") 
-                        if first:
+# Draws vertical lines at selected temperature values (only once for each subplot, hence "first") 
+                        if (first and (data['atom'].collNLevels == coll_n_max)):
                             for tem in self.ref_tem:
                                 plt.axvline(tem, c='blue', alpha=0.4, ls=':')
                             lbl = "$\Omega$" + "(" + str(j) + "," + str(i) + ")"
-                            ax.text(0.95, 0.95, lbl, transform=ax.transAxes, ha="right", va="top")                                    
+                            ax.text(0.95, 0.95, lbl, transform=ax.transAxes, ha="right", va="top")   
+                            first_done = True                                 
                         # Maximum number of ticks to avoid overcrowding
                         ax.xaxis.set_major_locator(MaxNLocator(4))
                         ax.yaxis.set_major_locator(MaxNLocator(3))
             # The line type and identifier of each data set are stored for the legend
             legend_lines.append(mpl.lines.Line2D(tem_funct, tem_funct, color=data['color'], linestyle='-'))
             legend_text.append(data['ID'])
-            first = False
+            if first_done:
+                first = False
         # The label of the reference temperature values are only plotted above the last plot
         for tem in self.ref_tem:
-            ax.text(tem, ax.get_ylim()[1], ' %0.0f K' % (10 ** tem), ha="left", va="bottom", rotation=65, fontsize=12, color='#FF0000', alpha=0.35)
+            ax.text(tem, ax.get_ylim()[1], ' %0.0f K' % (10 ** tem), ha="left", va="bottom", 
+                    rotation=65, fontsize=12, color='#FF0000', alpha=0.35)
         # Axis labels, title and legend    
         fig.text(.5, .05, "Log($T_e/K$)", fontsize=16, ha='center', va='top')
         fig.text(.05, .5, "$\Omega$", va='center', fontsize=20, rotation=90)
-        fig.text(.5, .95, "[%s %s] collision strengths" % (self.elem, int_to_roman(int(self.spec))), color="#191970", fontsize=16, ha='center')
-        plt.legend(legend_lines, legend_text, loc='upper right', borderpad=1, labelspacing=1, bbox_to_anchor=(1, 1 * self.coll_n_max))
+        fig.text(.5, .95, "[%s %s] collision strengths" % (self.elem, int_to_roman(int(self.spec))), 
+                 color="#191970", fontsize=16, ha='center')
+        plt.legend(legend_lines, legend_text, loc='upper right', borderpad=1, 
+                   labelspacing=1, bbox_to_anchor=(1, 1 * coll_n_max))
         
         if save:
-            plt.gcf().set_size_inches(figsize[0], figsize[1])
-            plt.savefig(self.atom + "_CS.pdf")
+            plt.savefig(self.atom_rom + "_CS.pdf")
         
         plt.show()
 
@@ -442,6 +470,5 @@ class DataPlot(object):
             return np.multiply(tem, 1.e4)
         else: #T in Kelvin in the fits file
             return tem
-        
+                
     
-
