@@ -7,6 +7,8 @@ import pyneb as pn
 def execution_path(filename):
     return os.path.join(os.path.dirname(sys._getframe(1).f_code.co_filename), filename)
 
+def _returnNone(*argv, **kwargs):
+    return None
 
 def int_to_roman(input_):
     """
@@ -117,12 +119,14 @@ def parseAtom(atom):
 
     elem = ''
     spec = ''
+    cont = True
     for l in atom:
-        if l.isdigit():
-            spec = spec + l
-        if l.isalpha():
+        if l.isalpha() and cont:
             elem = elem + l
-    return elem, spec
+        elif l.isdigit():
+            spec = spec + l
+            cont = False
+    return str.capitalize(elem), spec
 
 
 def strExtract(text, par1=None, par2=None): 
@@ -265,3 +269,74 @@ def quiet_log10(a):
     revert_seterr(oldsettings)
     return to_return
      
+def get_reduced(N_rand, a, value_method = 'original', error_method='std'):
+    """
+    This function returns a tuple of value and error corresponding to an array of values 
+        obtained from a MonteCarlo computation
+    It takes as argument an array that contains the original value, 
+        followed by N_rand MonteCarlo values.
+    The relevant value is computed by returning the original value (default), the mean or the median, 
+        depending on "value_method"
+    The errors are computed by 68% quantiles or standart deviation (Default), 
+        depending on "error_method"
+    
+    """
+
+    if error_method == 'quants' and not pn.config.INSTALLED['scipy']:
+        pn.log_.error('Scipy not installed, use_quants not available', calling = 'get_reduced')
+    else:
+        from scipy.stats.mstats import mquantiles
+    
+    value = a[0]
+    error = a.std()
+    
+    if value_method == 'mean':
+        value = a.mean()
+    elif value_method == 'median':
+        value = np.median(a)
+    
+    if error_method == 'quants':
+        quants = mquantiles(a, [0.16, 0.84])
+        error = np.abs(quants - value).mean()
+        # error = (quants[1]-quants[0])/2)
+    
+    return (value, error)
+    
+def get_reduced_dic(N_rand, n_obs_ori, dic, value_method = 'original', error_method='std', abund12 = False):
+    """
+    This function returns a dictionary of values (ionic or atomic abundances, temp...) and errors.
+    It takes as argument a dictionary that is supposed to contains n_obs_ori values from
+        the original observations, followed (optionaly) by N_rand*n_obs_ori MonteCarlo values.
+    The new values are computed by returning the original value (default), the mean or the median, 
+        depending on "value_method"
+    The errors are computed by 68% quantiles or standart deviation (Default), depending on on "error_method"
+    
+    It also transforms the abundances by number into 12+log10(abundances by number)
+    """
+    res = {}
+    for key in dic:
+        value = []
+        error = []
+        for i in np.arange(n_obs_ori):
+            if abund12:
+                values = 12 + np.log10(dic[key][n_obs_ori+i*N_rand:n_obs_ori+(i+1)*N_rand])
+                values = np.insert(values, 0, 12 + np.log10(dic[key][i]))
+            else:
+                values = dic[key][n_obs_ori+i*N_rand:n_obs_ori+(i+1)*N_rand]
+                values = np.insert(values, 0, dic[key][i])
+            tt = np.isfinite(values)
+            if tt.sum() == 0:
+                value.append(np.NAN)
+                error.append(0.0)
+            else:
+                v, e = get_reduced(N_rand, values[tt], value_method = value_method, error_method=error_method)
+                value.append(v)
+                error.append(e)
+        res[key] = np.array(value)
+        res['{0}_e'.format(key)] = np.array(error)
+    return res
+
+    
+    
+    
+    
\ No newline at end of file
