@@ -143,12 +143,13 @@ sym2name = {
 gsDict = {
             'p1': ['C2', 'N3', 'O4', 'Si2', 'S4', 'Se4', 'Xe6'],
             'p2': ['N2', 'O3', 'Ne5', 'S3', 'Cl4', 'Ar5', 'Se3', 'Kr5', 'Xe5', 'Rb6'],
-            'p3': ['N1', 'O2', 'Ne4', 'Na5', 'S2', 'Cl3', 'Ar4', 'K5', 'Se2', 'Kr4', 'Xe4','Rb5'],
+            'p3': ['N1', 'O2', 'Ne4', 'Na5', 'S2', 'Cl3', 'Ar4', 'K5', 'Se2', 'Kr4', 'Xe4', 'Rb5', 'Br3'],
             'p4': ['O1', 'Ne3', 'Na4', 'Mg5', 'Cl2', 'Ar3', 'K4', 'Ca5', 'Kr3', 'Xe3', 'Rb4'],
             'p5': ['Ne2', 'Na3', 'Si6', 'Cl1', 'Ar2', 'K3', 'Ba4'],
             's1': ['C4', 'N5', 'Ba2'],
             's2': ['C3', 'N4', 'O5', 'Si3'],
-            'd6': ['Fe3']
+            'd6': ['Fe3'],
+            'd8': ['Ni3']
             }
 
 def gsFromAtom(atom):
@@ -166,7 +167,8 @@ gsLevelDict = {
             'p5': ['$^2$P$_{3/2}$', '$^2$P$_{1/2}$'],
             's1': ['$^2$S$_{1/2}$', '$^2$P$_{1/2}$', '$^2$P$_{3/2}$'],
             's2': ['$^1$S$_0$', '$^3$P$_0$', '$^3$P$_1$', '$^3$P$_2$', '$^1$P$_1$'],
-            'd6': ['$^5$D$_4$', '$^5$D$_3$', '$^5$D$_2$', '$^5$D$_1$', '$^5$D$_0$', '$^3$P2$_2$', '$^3$H$_6$']
+            'd6': ['$^5$D$_4$', '$^5$D$_3$', '$^5$D$_2$', '$^5$D$_1$', '$^5$D$_0$', '$^3$P2$_2$', '$^3$H$_6$'], 
+            'd8': ['$3$F$_4$', '$^3$F$_3$', '$^3$F$_2$', '$^1$D$_2$', '$^3$P$_2$', '$^3$P2$_1$', '$^3$P$_0$']
             }
 
 
